@@ -37,7 +37,5 @@ int main(int argc, char **argv) {
 	tcc_delete(s_second);
 	pass("cleanup");
 	
-	done_testing();
-	
-	return 0;
+	return done_testing();
 }
